@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,17 +20,16 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.accessapproval_v1.services.access_approval import pagers
 from google.cloud.accessapproval_v1.types import accessapproval
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import AccessApprovalTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import AccessApprovalGrpcAsyncIOTransport
 from .client import AccessApprovalClient
@@ -87,35 +84,61 @@ class AccessApprovalAsyncClient:
     parse_common_billing_account_path = staticmethod(
         AccessApprovalClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(AccessApprovalClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         AccessApprovalClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         AccessApprovalClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         AccessApprovalClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(AccessApprovalClient.common_project_path)
     parse_common_project_path = staticmethod(
         AccessApprovalClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(AccessApprovalClient.common_location_path)
     parse_common_location_path = staticmethod(
         AccessApprovalClient.parse_common_location_path
     )
 
-    from_service_account_file = AccessApprovalClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            AccessApprovalAsyncClient: The constructed client.
+        """
+        return AccessApprovalClient.from_service_account_info.__func__(AccessApprovalAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            AccessApprovalAsyncClient: The constructed client.
+        """
+        return AccessApprovalClient.from_service_account_file.__func__(AccessApprovalAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> AccessApprovalTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             AccessApprovalTransport: The transport used by the client instance.
@@ -129,12 +152,12 @@ class AccessApprovalAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, AccessApprovalTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the access approval client.
+        """Instantiates the access approval client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -166,7 +189,6 @@ class AccessApprovalAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = AccessApprovalClient(
             credentials=credentials,
             transport=transport,
@@ -189,16 +211,16 @@ class AccessApprovalAsyncClient:
         order is reverse chronological.
 
         Args:
-            request (:class:`~.accessapproval.ListApprovalRequestsMessage`):
+            request (:class:`google.cloud.accessapproval_v1.types.ListApprovalRequestsMessage`):
                 The request object. Request to list approval requests.
             parent (:class:`str`):
                 The parent resource. This may be
                 "projects/{project_id}", "folders/{folder_id}", or
                 "organizations/{organization_id}".
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -206,7 +228,7 @@ class AccessApprovalAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListApprovalRequestsAsyncPager:
+            google.cloud.accessapproval_v1.services.access_approval.pagers.ListApprovalRequestsAsyncPager:
                 Response to listing of
                 ApprovalRequest objects.
                 Iterating over this object will yield
@@ -228,7 +250,6 @@ class AccessApprovalAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -240,7 +261,10 @@ class AccessApprovalAsyncClient:
                 initial=0.1,
                 maximum=60.0,
                 multiplier=1.3,
-                predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
+                predicate=retries.if_exception_type(
+                    core_exceptions.ServiceUnavailable,
+                ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -277,15 +301,15 @@ class AccessApprovalAsyncClient:
         not exist.
 
         Args:
-            request (:class:`~.accessapproval.GetApprovalRequestMessage`):
+            request (:class:`google.cloud.accessapproval_v1.types.GetApprovalRequestMessage`):
                 The request object. Request to get an approval request.
             name (:class:`str`):
                 Name of the approval request to
                 retrieve.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -293,7 +317,7 @@ class AccessApprovalAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.accessapproval.ApprovalRequest:
+            google.cloud.accessapproval_v1.types.ApprovalRequest:
                 A request for the customer to approve
                 access to a resource.
 
@@ -312,7 +336,6 @@ class AccessApprovalAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -324,7 +347,10 @@ class AccessApprovalAsyncClient:
                 initial=0.1,
                 maximum=60.0,
                 multiplier=1.3,
-                predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
+                predicate=retries.if_exception_type(
+                    core_exceptions.ServiceUnavailable,
+                ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -357,10 +383,9 @@ class AccessApprovalAsyncClient:
         pending state.
 
         Args:
-            request (:class:`~.accessapproval.ApproveApprovalRequestMessage`):
+            request (:class:`google.cloud.accessapproval_v1.types.ApproveApprovalRequestMessage`):
                 The request object. Request to approve an
                 ApprovalRequest.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -368,13 +393,12 @@ class AccessApprovalAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.accessapproval.ApprovalRequest:
+            google.cloud.accessapproval_v1.types.ApprovalRequest:
                 A request for the customer to approve
                 access to a resource.
 
         """
         # Create or coerce a protobuf request object.
-
         request = accessapproval.ApproveApprovalRequestMessage(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -417,10 +441,9 @@ class AccessApprovalAsyncClient:
         a pending state.
 
         Args:
-            request (:class:`~.accessapproval.DismissApprovalRequestMessage`):
+            request (:class:`google.cloud.accessapproval_v1.types.DismissApprovalRequestMessage`):
                 The request object. Request to dismiss an approval
                 request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -428,13 +451,12 @@ class AccessApprovalAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.accessapproval.ApprovalRequest:
+            google.cloud.accessapproval_v1.types.ApprovalRequest:
                 A request for the customer to approve
                 access to a resource.
 
         """
         # Create or coerce a protobuf request object.
-
         request = accessapproval.DismissApprovalRequestMessage(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -470,16 +492,16 @@ class AccessApprovalAsyncClient:
         or organization.
 
         Args:
-            request (:class:`~.accessapproval.GetAccessApprovalSettingsMessage`):
+            request (:class:`google.cloud.accessapproval_v1.types.GetAccessApprovalSettingsMessage`):
                 The request object. Request to get access approval
                 settings.
             name (:class:`str`):
                 Name of the AccessApprovalSettings to
                 retrieve.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -487,7 +509,7 @@ class AccessApprovalAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.accessapproval.AccessApprovalSettings:
+            google.cloud.accessapproval_v1.types.AccessApprovalSettings:
                 Settings on a
                 Project/Folder/Organization related to
                 Access Approval.
@@ -507,7 +529,6 @@ class AccessApprovalAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -519,7 +540,10 @@ class AccessApprovalAsyncClient:
                 initial=0.1,
                 maximum=60.0,
                 multiplier=1.3,
-                predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
+                predicate=retries.if_exception_type(
+                    core_exceptions.ServiceUnavailable,
+                ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -542,7 +566,7 @@ class AccessApprovalAsyncClient:
         request: accessapproval.UpdateAccessApprovalSettingsMessage = None,
         *,
         settings: accessapproval.AccessApprovalSettings = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -552,15 +576,15 @@ class AccessApprovalAsyncClient:
         field_mask.
 
         Args:
-            request (:class:`~.accessapproval.UpdateAccessApprovalSettingsMessage`):
+            request (:class:`google.cloud.accessapproval_v1.types.UpdateAccessApprovalSettingsMessage`):
                 The request object. Request to update access approval
                 settings.
-            settings (:class:`~.accessapproval.AccessApprovalSettings`):
+            settings (:class:`google.cloud.accessapproval_v1.types.AccessApprovalSettings`):
                 The new AccessApprovalSettings.
                 This corresponds to the ``settings`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                 The update mask applies to the settings. Only the top
                 level fields of AccessApprovalSettings
                 (notification_emails & enrolled_services) are supported.
@@ -572,10 +596,10 @@ class AccessApprovalAsyncClient:
                 https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
                 If this field is left unset, only the
                 notification_emails field will be updated.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -583,7 +607,7 @@ class AccessApprovalAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.accessapproval.AccessApprovalSettings:
+            google.cloud.accessapproval_v1.types.AccessApprovalSettings:
                 Settings on a
                 Project/Folder/Organization related to
                 Access Approval.
@@ -603,7 +627,6 @@ class AccessApprovalAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if settings is not None:
             request.settings = settings
         if update_mask is not None:
@@ -650,16 +673,16 @@ class AccessApprovalAsyncClient:
         inherited.
 
         Args:
-            request (:class:`~.accessapproval.DeleteAccessApprovalSettingsMessage`):
+            request (:class:`google.cloud.accessapproval_v1.types.DeleteAccessApprovalSettingsMessage`):
                 The request object. Request to delete access approval
                 settings.
             name (:class:`str`):
                 Name of the AccessApprovalSettings to
                 delete.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -680,7 +703,6 @@ class AccessApprovalAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
