@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,12 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -56,7 +53,6 @@ class EnrollmentLevel(proto.Enum):
 
 class AccessLocations(proto.Message):
     r"""Home office and physical location of the principal.
-
     Attributes:
         principal_office_country (str):
             The "home office" location of the principal.
@@ -94,16 +90,14 @@ class AccessLocations(proto.Message):
             - ANY: Any location
     """
 
-    principal_office_country = proto.Field(proto.STRING, number=1)
-
-    principal_physical_location_country = proto.Field(proto.STRING, number=2)
+    principal_office_country = proto.Field(proto.STRING, number=1,)
+    principal_physical_location_country = proto.Field(proto.STRING, number=2,)
 
 
 class AccessReason(proto.Message):
     r"""
-
     Attributes:
-        type_ (~.accessapproval.AccessReason.Type):
+        type_ (google.cloud.accessapproval_v1.types.AccessReason.Type):
             Type of access justification.
         detail (str):
             More detail about certain reason types. See
@@ -118,8 +112,7 @@ class AccessReason(proto.Message):
         GOOGLE_INITIATED_REVIEW = 3
 
     type_ = proto.Field(proto.ENUM, number=1, enum=Type,)
-
-    detail = proto.Field(proto.STRING, number=2)
+    detail = proto.Field(proto.STRING, number=2,)
 
 
 class ApproveDecision(proto.Message):
@@ -127,44 +120,44 @@ class ApproveDecision(proto.Message):
     resource.
 
     Attributes:
-        approve_time (~.timestamp.Timestamp):
+        approve_time (google.protobuf.timestamp_pb2.Timestamp):
             The time at which approval was granted.
-        expire_time (~.timestamp.Timestamp):
+        expire_time (google.protobuf.timestamp_pb2.Timestamp):
             The time at which the approval expires.
     """
 
-    approve_time = proto.Field(proto.MESSAGE, number=1, message=timestamp.Timestamp,)
-
-    expire_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
+    approve_time = proto.Field(
+        proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,
+    )
+    expire_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
 
 
 class DismissDecision(proto.Message):
     r"""A decision that has been made to dismiss an approval request.
-
     Attributes:
-        dismiss_time (~.timestamp.Timestamp):
+        dismiss_time (google.protobuf.timestamp_pb2.Timestamp):
             The time at which the approval request was
             dismissed.
     """
 
-    dismiss_time = proto.Field(proto.MESSAGE, number=1, message=timestamp.Timestamp,)
+    dismiss_time = proto.Field(
+        proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,
+    )
 
 
 class ResourceProperties(proto.Message):
     r"""The properties associated with the resource of the request.
-
     Attributes:
         excludes_descendants (bool):
             Whether an approval will exclude the
             descendants of the resource being requested.
     """
 
-    excludes_descendants = proto.Field(proto.BOOL, number=1)
+    excludes_descendants = proto.Field(proto.BOOL, number=1,)
 
 
 class ApprovalRequest(proto.Message):
     r"""A request for the customer to approve access to a resource.
-
     Attributes:
         name (str):
             The resource name of the request. Format is
@@ -178,52 +171,46 @@ class ApprovalRequest(proto.Message):
             or a "relative" resource name (e.g.
             "shelves/shelf1/books/book2") as described in the resource
             name specification.
-        requested_resource_properties (~.accessapproval.ResourceProperties):
+        requested_resource_properties (google.cloud.accessapproval_v1.types.ResourceProperties):
             Properties related to the resource represented by
             requested_resource_name.
-        requested_reason (~.accessapproval.AccessReason):
+        requested_reason (google.cloud.accessapproval_v1.types.AccessReason):
             The justification for which approval is being
             requested.
-        requested_locations (~.accessapproval.AccessLocations):
+        requested_locations (google.cloud.accessapproval_v1.types.AccessLocations):
             The locations for which approval is being
             requested.
-        request_time (~.timestamp.Timestamp):
+        request_time (google.protobuf.timestamp_pb2.Timestamp):
             The time at which approval was requested.
-        requested_expiration (~.timestamp.Timestamp):
+        requested_expiration (google.protobuf.timestamp_pb2.Timestamp):
             The requested expiration for the approval. If
             the request is approved, access will be granted
             from the time of approval until the expiration
             time.
-        approve (~.accessapproval.ApproveDecision):
+        approve (google.cloud.accessapproval_v1.types.ApproveDecision):
             Access was approved.
-        dismiss (~.accessapproval.DismissDecision):
+        dismiss (google.cloud.accessapproval_v1.types.DismissDecision):
             The request was dismissed.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    requested_resource_name = proto.Field(proto.STRING, number=2)
-
+    name = proto.Field(proto.STRING, number=1,)
+    requested_resource_name = proto.Field(proto.STRING, number=2,)
     requested_resource_properties = proto.Field(
         proto.MESSAGE, number=9, message="ResourceProperties",
     )
-
     requested_reason = proto.Field(proto.MESSAGE, number=3, message="AccessReason",)
-
     requested_locations = proto.Field(
         proto.MESSAGE, number=4, message="AccessLocations",
     )
-
-    request_time = proto.Field(proto.MESSAGE, number=5, message=timestamp.Timestamp,)
-
+    request_time = proto.Field(
+        proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
+    )
     requested_expiration = proto.Field(
-        proto.MESSAGE, number=6, message=timestamp.Timestamp,
+        proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,
     )
-
     approve = proto.Field(
         proto.MESSAGE, number=7, oneof="decision", message="ApproveDecision",
     )
-
     dismiss = proto.Field(
         proto.MESSAGE, number=8, oneof="decision", message="DismissDecision",
     )
@@ -248,12 +235,11 @@ class EnrolledService(proto.Message):
             - iam.googleapis.com
             - pubsub.googleapis.com
             - storage.googleapis.com
-        enrollment_level (~.accessapproval.EnrollmentLevel):
+        enrollment_level (google.cloud.accessapproval_v1.types.EnrollmentLevel):
             The enrollment level of the service.
     """
 
-    cloud_product = proto.Field(proto.STRING, number=1)
-
+    cloud_product = proto.Field(proto.STRING, number=1,)
     enrollment_level = proto.Field(proto.ENUM, number=2, enum="EnrollmentLevel",)
 
 
@@ -275,7 +261,7 @@ class AccessApprovalSettings(proto.Message):
             resource will be sent to all emails in the
             settings of ancestor resources of that resource.
             A maximum of 50 email addresses are allowed.
-        enrolled_services (Sequence[~.accessapproval.EnrolledService]):
+        enrolled_services (Sequence[google.cloud.accessapproval_v1.types.EnrolledService]):
             A list of Google Cloud Services for which the given resource
             has Access Approval enrolled. Access requests for the
             resource given by name against any of these services
@@ -300,20 +286,16 @@ class AccessApprovalSettings(proto.Message):
             ancestors).
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    notification_emails = proto.RepeatedField(proto.STRING, number=2)
-
+    name = proto.Field(proto.STRING, number=1,)
+    notification_emails = proto.RepeatedField(proto.STRING, number=2,)
     enrolled_services = proto.RepeatedField(
         proto.MESSAGE, number=3, message="EnrolledService",
     )
-
-    enrolled_ancestor = proto.Field(proto.BOOL, number=4)
+    enrolled_ancestor = proto.Field(proto.BOOL, number=4,)
 
 
 class ListApprovalRequestsMessage(proto.Message):
     r"""Request to list approval requests.
-
     Attributes:
         parent (str):
             The parent resource. This may be "projects/{project_id}",
@@ -335,20 +317,16 @@ class ListApprovalRequestsMessage(proto.Message):
             return.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    filter = proto.Field(proto.STRING, number=2)
-
-    page_size = proto.Field(proto.INT32, number=3)
-
-    page_token = proto.Field(proto.STRING, number=4)
+    parent = proto.Field(proto.STRING, number=1,)
+    filter = proto.Field(proto.STRING, number=2,)
+    page_size = proto.Field(proto.INT32, number=3,)
+    page_token = proto.Field(proto.STRING, number=4,)
 
 
 class ListApprovalRequestsResponse(proto.Message):
     r"""Response to listing of ApprovalRequest objects.
-
     Attributes:
-        approval_requests (Sequence[~.accessapproval.ApprovalRequest]):
+        approval_requests (Sequence[google.cloud.accessapproval_v1.types.ApprovalRequest]):
             Approval request details.
         next_page_token (str):
             Token to retrieve the next page of results,
@@ -362,66 +340,59 @@ class ListApprovalRequestsResponse(proto.Message):
     approval_requests = proto.RepeatedField(
         proto.MESSAGE, number=1, message="ApprovalRequest",
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetApprovalRequestMessage(proto.Message):
     r"""Request to get an approval request.
-
     Attributes:
         name (str):
             Name of the approval request to retrieve.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ApproveApprovalRequestMessage(proto.Message):
     r"""Request to approve an ApprovalRequest.
-
     Attributes:
         name (str):
             Name of the approval request to approve.
-        expire_time (~.timestamp.Timestamp):
+        expire_time (google.protobuf.timestamp_pb2.Timestamp):
             The expiration time of this approval.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    expire_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
+    name = proto.Field(proto.STRING, number=1,)
+    expire_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
 
 
 class DismissApprovalRequestMessage(proto.Message):
     r"""Request to dismiss an approval request.
-
     Attributes:
         name (str):
             Name of the ApprovalRequest to dismiss.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class GetAccessApprovalSettingsMessage(proto.Message):
     r"""Request to get access approval settings.
-
     Attributes:
         name (str):
             Name of the AccessApprovalSettings to
             retrieve.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateAccessApprovalSettingsMessage(proto.Message):
     r"""Request to update access approval settings.
-
     Attributes:
-        settings (~.accessapproval.AccessApprovalSettings):
+        settings (google.cloud.accessapproval_v1.types.AccessApprovalSettings):
             The new AccessApprovalSettings.
-        update_mask (~.field_mask.FieldMask):
+        update_mask (google.protobuf.field_mask_pb2.FieldMask):
             The update mask applies to the settings. Only the top level
             fields of AccessApprovalSettings (notification_emails &
             enrolled_services) are supported. For each field, if it is
@@ -436,19 +407,19 @@ class UpdateAccessApprovalSettingsMessage(proto.Message):
     """
 
     settings = proto.Field(proto.MESSAGE, number=1, message="AccessApprovalSettings",)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class DeleteAccessApprovalSettingsMessage(proto.Message):
     r"""Request to delete access approval settings.
-
     Attributes:
         name (str):
             Name of the AccessApprovalSettings to delete.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
